package com.example.admin.notice;

import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.example.admindashboard.R;
import com.google.android.gms.tasks.OnCompleteListener;
import com.google.android.gms.tasks.OnFailureListener;
import com.google.android.gms.tasks.Task;
import com.google.firebase.database.DatabaseReference;
import com.google.firebase.database.FirebaseDatabase;
import com.squareup.picasso.Picasso;

import java.util.ArrayList;

import es.dmoral.toasty.Toasty;

public class NoticeAdapter extends RecyclerView.Adapter<NoticeAdapter.NoticeViewAdapter> {

private Context context;
private ArrayList<NoticeData> list;


public NoticeAdapter(Context context, ArrayList<NoticeData> list) {
    this.context = context;
    this.list = list;
}

@NonNull
@Override
public NoticeViewAdapter onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {

    View view = LayoutInflater.from(context).inflate(R.layout.newss, parent,false);
    return new NoticeViewAdapter(view);
}

@Override
public void onBindViewHolder(@NonNull NoticeViewAdapter holder, int position) {

    NoticeData currentItem = list.get(position);


    holder.deleteNoticeTitle.setText(currentItem.getTitle());

    try {
        if (currentItem.getImage() != null)
            Picasso.get().load(currentItem.getImage()).into(holder.deleteNoticeImage);
    }catch (Exception e){
        e.printStackTrace();
    }
    holder.deleteNotice.setOnClickListener(new View.OnClickListener() {
        @Override
        public void onClick(View view) {

            AlertDialog.Builder builder = new AlertDialog.Builder(context);
            builder.setMessage("Are you sure want delete this notice?");
            builder.setCancelable(true);
            builder.setPositiveButton(

                    "Ok",
                    new DialogInterface.OnClickListener() {
                        @Override
                        public void onClick(DialogInterface dialogInterface, int i) {


                            DatabaseReference reference = FirebaseDatabase.getInstance().getReference().child("Notice");
                            reference.child(currentItem.getKey()).removeValue()
                                    .addOnCompleteListener(new OnCompleteListener<Void>() {
                                        @Override
                                        public void onComplete(@NonNull Task<Void> task) {
                                            Toasty.success(context, "Deleted", Toasty.LENGTH_SHORT).show();
                                        }
                                    }).addOnFailureListener(new OnFailureListener() {
                                @Override
                                public void onFailure(@NonNull Exception e) {
                                    Toasty.error(context, "Something went wrong", Toasty.LENGTH_SHORT).show();
                                }
                            });
                            notifyItemRemoved(position);
                        }
                    }
            );
            builder.setNegativeButton(
                    "Cancel",
                    new DialogInterface.OnClickListener() {
                        @Override
                        public void onClick(DialogInterface dialogInterface, int i) {
                            dialogInterface.cancel();
                        }
                    }
            );
            AlertDialog dialog = null;
            try {
                dialog = builder.create();
            }catch (Exception e){
                e.printStackTrace();
            }
            if (dialog != null)
                dialog.show();

        }
    });

}

@Override
public int getItemCount() {
    return list.size();
}

public class NoticeViewAdapter extends RecyclerView.ViewHolder {

    private Button deleteNotice;
    private TextView deleteNoticeTitle;
    private ImageView deleteNoticeImage;


    public NoticeViewAdapter(@NonNull View itemView) {
        super(itemView);
        deleteNotice = itemView.findViewById(R.id.deleteNotice);
        deleteNoticeTitle = itemView.findViewById(R.id.deleteNoticeTitle);
        deleteNoticeImage = itemView.findViewById(R.id.deleteNoticeImage);
    }
}
}
